@@ -1,6 +1,6 @@
 # pROC: Tools Receiver operating characteristic (ROC curves) with
 # (partial) area under the curve, confidence intervals and comparison. 
-# Copyright (C) 2010, 2011 Xavier Robin, Alexandre Hainard, Natacha Turck,
+# Copyright (C) 2010-2014 Xavier Robin, Alexandre Hainard, Natacha Turck,
 # Natalia Tiberti, Frédérique Lisacek, Jean-Charles Sanchez
 # and Markus Müller
 #
@@ -26,6 +26,7 @@ ci.multiclass.roc <- function(multiclass.roc,
                    boot.stratified = TRUE,
                    reuse.auc=TRUE,
                    progress = getOption("pROCProgress")$name,
+                   parallel = FALSE,
                    ...
                    ) {
   if (conf.level > 1 | conf.level < 0)
@@ -45,7 +46,7 @@ ci.multiclass.roc <- function(multiclass.roc,
       attr(multiclass.roc$auc, "partial.auc") <- attr(multiclass.roc$auc, "partial.auc") / 100
   }
 
-  ci <- ci.multiclass.auc.bootstrap(multiclass.roc, conf.level, boot.n, boot.stratified, progress, ...)
+  ci <- ci.multiclass.auc.bootstrap(multiclass.roc, conf.level, boot.n, boot.stratified, progress, parallel, ...)
 
   if (percent) {
     ci <- ci * 100
@@ -57,4 +58,3 @@ ci.multiclass.roc <- function(multiclass.roc,
   class(ci) <- "ci.multiclass.auc"
   return(ci)
 }
-
