@@ -219,9 +219,12 @@ sort.smooth.roc <- function(roc) {
 }
 
 # Arguments which can be returned by coords
-roc.utils.match.coords.ret.args <- function(x) {
-
-  valid.ret.args <- c("threshold", "specificity", "sensitivity", "accuracy", "tn", "tp", "fn", "fp", "npv", "ppv", "1-specificity", "1-sensitivity", "1-accuracy", "1-npv", "1-ppv")
+# @param threshold: FALSE for smooth.roc where threshold isn't valid
+roc.utils.match.coords.ret.args <- function(x, threshold = TRUE) {
+  valid.ret.args <- c("specificity", "sensitivity", "accuracy", "tn", "tp", "fn", "fp", "npv", "ppv", "1-specificity", "1-sensitivity", "1-accuracy", "1-npv", "1-ppv", "precision", "recall")
+  if (threshold) {
+  	valid.ret.args <- c("threshold", valid.ret.args)
+  }
   x <- replace(x, x=="t", "threshold")
   x <- replace(x, x=="npe", "1-npv")
   x <- replace(x, x=="ppe", "1-ppv")
